==> freifunk-openwrt-kit-1.6.37-0xff.tar.gz: www/cgi-bin/cgi-bin-pre.sh <==
#!/bin/sh
echo Content-type: text/html
echo

cat<<EOF
<HTML>
<HEAD>
<TITLE>$(n=$(nvram get wan_hostname);echo ${n:-Funkfeuer.At}) - $TITLE</TITLE>
<META CONTENT="text/html; charset=iso-8859-1" HTTP-EQUIV="Content-Type">
<META CONTENT="no-cache" HTTP-EQUIV="cache-control">
<LINK HREF="../0xff.css" REL="StyleSheet">
<LINK HREF="sven-ola*t*gmx*de" REV="made" TITLE="Sven-Ola">
EOF

unescape()
{
s=$(echo "$1"|sed -e"s/+/%20/g")
echo -n ${s%%%*}
if [ -n "$s" ] && [ "$s" != "${s#*%}" ];then
IFS=\%
set ${s#*%}
unset IFS
for i in "$@";do
echo -n -e "\\x$(echo $i|dd bs=1 count=2 2>&-)"
echo -n ${i#??}
done
fi
}
checkbridge()
{
ret=0
. /etc/functions.sh
dev=$(nvram get wifi_ifname)
if [ -z "$dev" ]; then
# 8Mb device may die in S15ffnvram, so correct
dev=$(sed -n 's/^ *\([^:]\+\):.*/\1/p' /proc/net/wireless)
if [ -n "$dev" ]; then
nvram set wifi_ifname=$dev
ret=1
fi
fi
if [ -n "$dev" ]; then
fnd=
old="$(nvram get lan_ifnames)"
for i in $old; do
test "$i" = "$dev" && fnd=1
done
wbr=
adr=$(nvram get wifi_ipaddr)
if [ -z "$adr" ] || [ "$adr" = "$(nvram get lan_ipaddr)" ];then
# WIFI dev should be in the bridge list
wbr=1
fi
if [ "$wbr" != "$fnd" ]; then
if [ -z "$wbr" ]; then
new=
for i in $old; do
test "$i" != "$dev" && new="$new $i"
done
new=${new# }
else
new="$old $dev"
fi
/usr/sbin/nvram set lan_ifnames="$new"
if [ -z "$(/usr/sbin/nvram get lan_ifname)" ]; then
lan=$(nvram get lan_ifname)
test -z "$lan" || lan=br0
nvram set lan_ifname=$lan
fi
ret=1
fi
fi
return $ret
}

cat<<EOF
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript"><!--
function help(e) {
if (!e) e = event;
// (virt)KeyVal is Konqueror, charCode is Moz/Firefox, else MSIE, Netscape, Opera
if (26 == e.virtKeyVal || !e.keyVal && !e.charCode && 112 == (e.which || e.keyCode)) {
var o = null;
if (e.preventDefault) {
if (e.cancelable) e.preventDefault();
o = e.target;
}
else {
e.cancelBubble = true;
o = e.srcElement;
}
while(!!o && '' == o.title) o = o.parentNode;
if (!!o) alert(o.title);
}
}
if (document.all) {
document.onkeydown = help;
document.onhelp = function(){return false;}
}
else {
document.onkeypress = help;
}
//--></SCRIPT>
</HEAD>
<BODY>
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" CLASS="body">
<TR>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="orange" COLSPAN="4">
<TABLE BORDER="0" CELLPADDING="6" CELLSPACING="0" WIDTH="100%">
<TR>
<TD ALIGN="left" VALIGN="TOP"><SMALL>v1.6.37</SMALL></TD>
<TD ALIGN="right" ROWSPAN="2" VALIGN="bottom"><A HREF="http://www.funkfeuer.at/"><IMG ALT="Funkfeuer.at" BORDER="0" HEIGHT="64" SRC="../images/0xff.gif" WIDTH="243" TITLE="Funkfeuer.at"></A></TD>
</TR>
<TR>
<TD ALIGN="left" VALIGN="bottom"><A CLASS="orange" HREF="../cgi-bin-index.html">Home</A>
<A CLASS="orange" HREF="index.html">Verwalten</A></TD>
</TR>
</TABLE></TD>
<TD WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="100%" VALIGN="top">
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" WIDTH="150">
<TR>
<TD><BIG CLASS="plugin">Verwalten</BIG></TD>
</TR>
EOF

for inc in /www/cgi-bin/[0-9][0-9]-*;do test -n "${inc##*.sh}" && cat $inc ||. $inc;done

cat<<EOF
</TABLE></TD>
<TD CLASS="color" HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="100%" VALIGN="top" WIDTH="100%">
EOF

==> freifunk-openwrt-kit-1.7.4-0xff.tar.gz: www/cgi-bin/cgi-bin-pre.sh <==
#!/bin/sh
echo Content-type: text/html
echo

cat<<EOF
<HTML>
<HEAD>
<TITLE>$(n=$(nvram get wan_hostname);echo ${n:-Funkfeuer.At}) - $TITLE</TITLE>
<META CONTENT="text/html; charset=iso-8859-1" HTTP-EQUIV="Content-Type">
<META CONTENT="no-cache" HTTP-EQUIV="cache-control">
<LINK HREF="../0xff.css" REL="StyleSheet">
<LINK HREF="sven-ola*t*gmx*de" REV="made" TITLE="Sven-Ola">
EOF

unescape()
{
eval echo -n -e '$(sed "s/+/%20/g;s/%\\([[:xdigit:]][[:xdigit:]]\\)/\\\\x\\1/g"<<ESC
$1
ESC
)'
}
checkbridge()
{
ret=0
. /etc/functions.sh
dev=$(nvram get wifi_ifname)
if [ -z "$dev" ]; then
# 8Mb device may die in S15ffnvram, so correct
dev=$(sed -n 's/^ *\([^:]\+\):.*/\1/p' /proc/net/wireless 2>&-)
if [ -n "$dev" ]; then
nvram set wifi_ifname=$dev
ret=1
fi
fi
if [ -n "$dev" ]; then
fnd=
old="$(nvram get lan_ifnames)"
for i in $old; do
test "$i" = "$dev" && fnd=1
done
wbr=
adr=$(nvram get wifi_ipaddr)
if [ -z "$adr" ] || [ "$adr" = "$(nvram get lan_ipaddr)" ];then
# WIFI dev should be in the bridge list
wbr=1
fi
if [ "$wbr" != "$fnd" ]; then
if [ -z "$wbr" ]; then
new=
for i in $old; do
test "$i" != "$dev" && new="$new $i"
done
new=${new# }
else
new="$old $dev"
fi
/usr/sbin/nvram set lan_ifnames="$new"
if [ -z "$(/usr/sbin/nvram get lan_ifname)" ]; then
lan=$(nvram get lan_ifname)
test -z "$lan" || lan=br0
nvram set lan_ifname=$lan
fi
ret=1
fi
fi
return $ret
}

cat<<EOF
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript"><!--
function help(e) {
if (!e) e = event;
// (virt)KeyVal is Konqueror, charCode is Moz/Firefox, else MSIE, Netscape, Opera
if (26 == e.virtKeyVal || !e.keyVal && !e.charCode && 112 == (e.which || e.keyCode)) {
var o = null;
if (e.preventDefault) {
if (e.cancelable) e.preventDefault();
o = e.target;
}
else {
e.cancelBubble = true;
o = e.srcElement;
}
while(!!o && '' == o.title) o = o.parentNode;
if (!!o) alert(o.title);
}
}
if (document.all) {
document.onkeydown = help;
document.onhelp = function(){return false;}
}
else {
document.onkeypress = help;
}
//--></SCRIPT>
</HEAD>
<BODY>
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" CLASS="body">
<TR>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="orange" COLSPAN="4">
<TABLE BORDER="0" CELLPADDING="6" CELLSPACING="0" WIDTH="100%">
<TR>
<TD ALIGN="left" VALIGN="TOP"><SMALL>v1.7.4<!--%FFVER%--></SMALL></TD>
<TD ALIGN="right" ROWSPAN="2" VALIGN="bottom"><A HREF="http://www.funkfeuer.at/"><IMG ALT="Funkfeuer.at" BORDER="0" HEIGHT="64" SRC="../images/0xff.gif" WIDTH="243" TITLE="Funkfeuer.at"></A></TD>
</TR>
<TR>
<TD ALIGN="left" VALIGN="bottom"><A CLASS="orange" HREF="../cgi-bin-index.html">Home</A>
<A CLASS="orange" HREF="index.html">Verwalten</A></TD>
</TR>
</TABLE></TD>
<TD WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="8" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
</TR>
<TR>
<TD CLASS="color" HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD CLASS="color" HEIGHT="100%" VALIGN="top">
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" WIDTH="150">
<TR>
<TD><BIG CLASS="plugin">Verwalten</BIG></TD>
</TR>
EOF

for inc in /www/cgi-bin/[0-9][0-9]-*;do case ${inc##*.sh} in ""). $inc;;*)cat $inc;;esac;done

cat<<EOF
</TABLE></TD>
<TD CLASS="color" HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="100%" VALIGN="top" WIDTH="8"><IMG HEIGHT="8" SRC="../images/8x8.gif" WIDTH="8"></TD>
<TD HEIGHT="100%" VALIGN="top" WIDTH="100%">
EOF
